#ifndef __OPTIONS_H_
#define __OPTIONS_H_

struct conf {
    char scsi[255];
    char cdrwdevice[256];
    char tempdir[256];
    char speed[3];
    char other[255];
    char blank[5];
    char logfile[256];
    char eject[2];
    char dao[2];
    char joliet[2];
    char rockridge[2];
    char usefulRR[2];
    char dummy[2];
    char volumeid[40];
    char cdrom[40];
    char showlog[2];
    char showvol[2];
    char pad[2];
    char fromimage[2];
    char multi[2];
    char burnproof[2];
    char mountpoint[40];
    char autodic[2];
    char audiodir[256];
    char bitsperchn[3];
    char stereo[2];
    char echosound[2];
    char encode[2];
    char lame[2];
    char highq[2];
    char bitrate[4];
    int cdsize;
    int user_cdsize;
    char cdbhost[255];
    char cdbuser[20];
    char sqlite_file[256];
    char bootimg[256];
};


int options_init(void);
void options_clean(void);

int read_conf(void);
int write_conf(void);

void options_window(void);


#endif /* __OPTIONS_H */
